==> haskell-clientsession-0.9.1.1-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-clientsession/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.1
id: clientsession-0.9.1.1-bfbde01c56aa03ce0bd7c91d723bab30
key: clien_3iELMQBuWzV1Ydqam88zQs
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/clientsession-0.9.1.1
hs-libraries: HSclientsession-0.9.1.1-3iELMQBuWzV1Ydqam88zQs
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cipher-aes-0.2.11-25252cf5003ba05bef45f1bdfd72c181
    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
    crypto-api-0.13.2-4fad3356ee1ec2ae527f720a8a7be373
    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
    skein-1.0.9.4-abff64cbe913b410d3c4ade70d46f3f9
    tagged-0.8.2-849e3b2865ae1877e32ec9d4d01c3d0a
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-clientsession-0.9.1.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-clientsession/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: clientsession
version: 0.9.1.1
id: clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
key: clien_LuobzRZeZj55iOint27HgG
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: stable
homepage: http://github.com/yesodweb/clientsession/tree/master
synopsis: Securely store session data in a client-side cookie.
description:
    Achieves security through AES-CTR encryption and
    Skein-MAC-512-256 authentication.  Uses Base64
    encoding to avoid any issues with characters.
category: Web
author: Michael Snoyman <michael@snoyman.com>, Felipe Lessa <felipe.lessa@gmail.com>
exposed: True
exposed-modules:
    Web.ClientSession
hidden-modules: System.LookupEnv
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/clientsession-0.9.1.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/clientsession-0.9.1.1
hs-libraries: HSclientsession-0.9.1.1-LuobzRZeZj55iOint27HgG
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
    cipher-aes-0.2.11-25252cf5003ba05bef45f1bdfd72c181
    cprng-aes-0.6.1-4f88e976d4e99640259c02d6940382c2
    crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
    crypto-random-0.0.9-1a34631cfa2fcb67c67a6201143b0147
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
    setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
    skein-1.0.9.4-403a459122a5f86f1575bd5c2d5cfd5a
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
haddock-interfaces: /usr/share/doc/haskell-clientsession/html/clientsession.haddock
haddock-html: /usr/share/doc/haskell-clientsession/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
